@@ -4,6 +4,7 @@ import re
 import requests
 
 CODEQ_API_ENDPOINT_LAST = 'https://api.codeq.com/v1'
+CODEQ_API_TEXT_SIMILARITY_ENDPOINT_LAST = 'https://api.codeq.com/v1_text_similarity'
 
 
 class OrderedClass(object):
@@ -123,6 +124,7 @@ class Sentence(OrderedClass):
     - paragraph: a number indicating the index paragrah of the sentence in the Document
     - tokens: a list of words
     - tokens_filtered: a list of words without stop words
+    - tokens_clean: a list of words without the artifacts that the prepocessing modules remove
     - stems: a list of stemmed words
     - lemmas: a list of lemmatized words
     - pos_tags: a list of Part of Speech tags, corresponding to each word in the list of tokens
@@ -155,6 +157,7 @@ class Sentence(OrderedClass):
         Additionally, each coreference dict contains a coreference chain (all the ids of the linked mentions)
         and the first referent of a chain.
     - compressed_sentence: a string with a a shortened version of a sentence.
+    - abuse: a list of types of abuse conveyed in a sentence
     """
 
     def __init__(self, raw_sentence):
@@ -163,6 +166,7 @@ class Sentence(OrderedClass):
         self.paragraph = None
         self.tokens = None
         self.tokens_filtered = None
+        self.tokens_clean = None
 
         self.stems = None
         self.lemmas = None
@@ -191,11 +195,10 @@ class Sentence(OrderedClass):
         self.nes_types = None
         self.nes_positions = None
 
+        self.sentiments = None
         self.emotions = None
         self.sarcasm = None
 
-        self.sentiments = None
-
         self.dates = None
 
         self.is_task = None
@@ -206,6 +209,8 @@ class Sentence(OrderedClass):
 
         self.compressed_sentence = None
 
+        self.abuse = None
+
     @property
     def tagged_sentence(self):
         if not self.pos_tags:
@@ -244,6 +249,7 @@ class CodeqClient(object):
         self.user_id = user_id
         self.user_key = user_key
         self.endpoint = CODEQ_API_ENDPOINT_LAST
+        self.endpoint_text_similarity = CODEQ_API_TEXT_SIMILARITY_ENDPOINT_LAST
 
     def language(self, text):
         return self.__run_request(text, pipeline='language')
@@ -326,6 +332,9 @@ class CodeqClient(object):
     def salience(self, text):
         return self.__run_request(text, pipeline='salience')
 
+    def abuse(self, text):
+        return self.__run_request(text, pipeline='abuse')
+
     @staticmethod
     def _json_to_class(cls, data):
         """
@@ -365,6 +374,21 @@ class CodeqClient(object):
         else:
             raise CodeqAPIError("%s; %s" % (request.status_code, request.reason))
 
+    def __run_request_text_similarity(self, text1, text2, pipeline):
+        params = {
+            'user_id': self.user_id,
+            'user_key': self.user_key,
+            'text1': text1,
+            'text2': text2,
+            'pipeline': pipeline
+        }
+        request = requests.post(url=self.endpoint_text_similarity, json=params)
+
+        if request.status_code == 200:
+            return request.text
+        else:
+            raise CodeqAPIError("%s; %s" % (request.status_code, request.reason))
+
     def analyze(self, text, pipeline=None, benchmark=False):
         """
         :param text: A string
@@ -378,3 +402,13 @@ class CodeqClient(object):
             pipeline = re.split(r'\s*,\s*', pipeline)
         document = self.__run_request(text, pipeline=pipeline, benchmark=benchmark)
         return document
+
+    def analyze_text_similarity(self, text1, text2):
+        """
+        :param text1: A string
+        :param text2: A string
+        :return: A dict containing a text similarity score
+        """
+        pipeline = 'text_similarity'
+        score = self.__run_request_text_similarity(text1, text2, pipeline=pipeline)
+        return score
